@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2011-2020 Canonical
+ * Copyright (C) 2011-2021 Canonical
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -1090,7 +1090,7 @@ static void info_banner_dump(
 	sz -= i;
 	(void)strncpy(ptr, "PID S  CPU    Time Task", sz);
 	ptr += 23;
-	sz -= 23;
+	/* sz -= 23; keep Coverity happy */
 
 	if (UNLIKELY(opt_flags & OPT_TIMESTAMP)) {
 		struct tm tm;
